### .LSM File (compiler metadata/symbol info) ###

The LSM file starts with a signature/version line (allowing client programs to verify that the file layout will be as expected. This is followed by one or more TOC entries which specify a table ID, size (hex), and offset (hex) from the start of the LSM file (to allow you to jump directly to it). The TOC is terminated by an entry with table ID 00. Following this are the actual tables, which have different layouts but are all CSV-compatible. Currently there are three tables defined: 01 (FILIDX), 02 (FNPIDX), and 03 (VARDEF). Each table starts with a header line repeating the table id followed by a list of the field names in the table. For example:

    [ASBSYMV001]
    01,0000138f,00000066
    02,00001c72,000013f5
    03,00023806,00003067
    00,00000000,00000000
    [01]: fno(-scope),fname
    0,c:\vm\miame\dsk43\241551\stevex.bas
    1,c:\vm\miame\dsk43\241551\stevex.ver
    ...
    [02]: scope,fnproc,fno,lno
    1,"FN'BUILD'ASSEM(FN'ASSEM'ITEM AS S15,FN'LEVEL'ID AS F6,F'QTY AS F6) ! 4.2(524)",0,557
    2,"FN'ADD'TO'ARRAY(LOCAL'KBMSTRC,LEVEL'NO AS F6, RECORD'TYPE AS S1, FN'PARENT'ARRAY'POS AS F6,F'QTY AS F6)",0,603
    3,"FN'SEARCH'STOCK'RECORD(FN'ITEM AS S15)",0,744
    4,"FN'SEARCH'STOCK'LOCATION(FN'ITEM AS S15,FN'LOC AS S2)",0,765
    ...
    [03]: maplvl,varname,vartyp,varsiz,offset,scope,fno,lno,struct
    1,VERSION,1,15,2,0,1,124,
    1,INVMAS,0,512,5370,0,3,30,
    2,ITEMNO,1,15,0,0,3,31,
    2,LOCATION,1,2,15,0,3,32,
    2,ITEMNO2,1,15,17,0,3,33,
    2,DESCR,1,40,32,0,3,34,
    2,PRDCAT,1,2,72,0,3,35,
    2,ALTITEM,1,13,74,0,3,37,
    2,ALTITEM'OVERLAY,0,13,74,0,3,38,
    3,CD'CE'LABEL'CODE,1,8,74,0,3,39,
    1,ST_HOOK_ENV,0,88,2,0,4,78,ST_HOOK_ENV
    2,ST_HOOK_ENV.event,3,4,0,0,4,78,
    ...

1. Table 01 (FILIDX) lists all the files included in the compilation.
    1. Each file is assigned an index number.
    1. Note that some may appear more than once because the file is included more than once.
1. Table 02 (FNPIDX) lists all the functions and procedures included in the compilation. 
    1. Each entry consists of:
        1. The index number
        1. The complete declaration of the func/proc
        1. The file index number that it is defined in
        1. The line number within that file.
1. Table 03 (VARDEF) lists all the variables defined, in the order they were defined. 
    1. Each entry consists of:
        1. The map level
        2. The variable name
        3. The type code
        4. Size in bytes
        5. The offset
            1. For map levels > 1, the offset is relative to the preceding map1 and thus can be used to display the structure offsets. 
            2. For map level 1, the offset is relative to 0. 
        6. The Scope
            1. The scope parameter identifies whether the variable is local (defined within a func/proc), module level, global. 
                1. If local, the scope will equal the numeric index of the func/proc from the FNPIDX table.
                2. If module level, it will be a negative value, whose absolute value matches the filidx # of the file where it is defined. For global, it will be 0.
        1. The file index number that it is defined in
        1. The line number within that file.
        1. The formal structure name if applicable
